#[non_exhaustive]pub enum EvaluationError {
UndefinedVariable {
name: String,
},
TypeMismatch {
expected: String,
found: String,
},
DivisionByZero,
FunctionNotFound {
name: String,
},
WrongArity {
name: String,
expected: usize,
got: usize,
},
JitCompilationError {
message: String,
},
UnsupportedOperation {
message: String,
},
}Expand description
Errors that can occur during expression evaluation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UndefinedVariable
A variable referenced in the expression was not provided.
TypeMismatch
A type mismatch occurred (e.g. integer where float was expected).
DivisionByZero
Division by zero.
FunctionNotFound
A user-defined function was not found in the registry.
WrongArity
A function was called with the wrong number of arguments.
Fields
JitCompilationError
JIT compilation failed.
UnsupportedOperation
The requested operation is not supported for this domain.