Module function_map

Module function_map 

Function registry for user-defined external functions.

The FunctionMap allows registering custom functions that can be called during expression evaluation via ExternalFun instructions.

Structs

FunctionEntry
A registered external function.
FunctionMap
A map of named functions that can be called during evaluation.